@@ -97,7 +97,6 @@ class Renderer(JsRenderer, JsCacheRenderer):
             actions={a.action_name: a for a in actions},
             # actors={a.actor_id: a for a in self.actors_list},
             menu=settings.SITE.get_site_menu(get_user_profile()),
-            choicelists=choicelists_data,
             suggestors=list(plugins.memo.parser.suggesters.keys()),  # [#,@] keytriggers
             )
 
@@ -114,13 +113,17 @@ class Renderer(JsRenderer, JsCacheRenderer):
         form_panels = {}
         for p in self.form_panels:
             form_panels[p._formpanel_name] = self.panel2json(p)
+            if hasattr(p, 'choice_name') and 'system.Dashboard' in p._formpanel_name:
+                for i, item in enumerate(choicelists_data['system.DashboardLayouts']):
+                    if item['value'] == p.choice_name:
+                        choicelists_data['system.DashboardLayouts'][i]['window_layout'] = p._formpanel_name
         for p in self.param_panels:
             form_panels[p._formpanel_name] = self.panel2json(p)
         for p in self.action_param_panels:
             form_panels[p._formpanel_name] = self.panel2json(p)
         for p in self.other_panels:
             form_panels[p._formpanel_name] = self.panel2json(p)
-        data.update(form_panels=form_panels)
+        data.update(form_panels=form_panels, choicelists=choicelists_data)
 
 
         # print("20210417", data)
@@ -366,6 +369,7 @@ class Renderer(JsRenderer, JsCacheRenderer):
             if v.select_rows: result['select_rows'] = v.select_rows
             if v.submit_form_data: result['submit_form_data'] = True
             if v.button_text: result['button_text'] = v.button_text
+            if v.help_text: result['help_text'] = v.help_text
 
             icon = self.get_action_icon(v)
             if icon: result['icon'] = icon
